==> haskell-cabal-helper-0.7.2.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-helper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.7.2.0
id: cabal-helper-0.7.2.0-FH8IN284FwsJWBNgbaXomn
key: cabal-helper-0.7.2.0-FH8IN284FwsJWBNgbaXomn
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state used by ghc-mod
description:
    @cabal-helper@ provides a library which wraps the internal use of an
    executable to lift the restrictions imposed by linking against versions of
    GHC before @7.10@. This has the pleasant side effect of isolating the user
    from having to deal with Cabal version changes manually as @cabal-helper@
    can simply recompile it'\''s helper program automatically as needed.
    .
    @cabal-helper@ uses a wrapper executable to compile the actual cabal-helper
    executable at runtime while linking against an arbitrary version of
    Cabal. This runtime-compiled helper executable is then used to extract
    various bits and peices from Cabal\'\''s on disk state (dist/setup-config)
    written by it'\''s configure command.
    .
    In addition to this the wrapper executable also supports installing any
    version of Cabal from hackage in case it cannot be found in any available
    package database. The wrapper installs these instances of the Cabal library
    into a private package database so as to not interfere with the user'\''s
    packages.
    .
    Furthermore the wrapper supports one special case namely reading a state
    file for Cabal itself. This is needed as Cabal compiles it'\''s Setup.hs using
    itself and not using any version of Cabal installed in any package database.
    .
    @cabal-helper@ can compile with @Cabal >= 1.14@ but requires @Cabal >= 1.16@
    at runtime.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
exposed-modules:
    Distribution.Helper
hidden-modules: Paths_cabal_helper CabalHelper.Types
                CabalHelper.Sandbox
abi: 7ce023257d263a5513976ed0d89bef79
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cabal-helper-0.7.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cabal-helper-0.7.2.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cabal-helper-0.7.2.0
hs-libraries: HScabal-helper-0.7.2.0-FH8IN284FwsJWBNgbaXomn
depends:
    Cabal-1.24.0.0 base-4.9.0.0 directory-1.2.6.2 filepath-1.4.1.0
    ghc-prim-0.5.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM process-1.4.2.0
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-helper-0.7.3.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-helper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.7.3.0
id: cabal-helper-0.7.3.0-8irtsA9yeTTAn5BCqOpvck
key: cabal-helper-0.7.3.0-8irtsA9yeTTAn5BCqOpvck
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state used by ghc-mod
description:
    @cabal-helper@ provides a library which wraps the internal use of an
    executable to lift the restrictions imposed by linking against versions of
    GHC before @7.10@. This has the pleasant side effect of isolating the user
    from having to deal with Cabal version changes manually as @cabal-helper@
    can simply recompile it'\''s helper program automatically as needed.
    .
    @cabal-helper@ uses a wrapper executable to compile the actual cabal-helper
    executable at runtime while linking against an arbitrary version of
    Cabal. This runtime-compiled helper executable is then used to extract
    various bits and peices from Cabal\'\''s on disk state (dist/setup-config)
    written by it'\''s configure command.
    .
    In addition to this the wrapper executable also supports installing any
    version of Cabal from hackage in case it cannot be found in any available
    package database. The wrapper installs these instances of the Cabal library
    into a private package database so as to not interfere with the user'\''s
    packages.
    .
    Furthermore the wrapper supports one special case namely reading a state
    file for Cabal itself. This is needed as Cabal compiles it'\''s Setup.hs using
    itself and not using any version of Cabal installed in any package database.
    .
    @cabal-helper@ can compile with @Cabal >= 1.14@ but requires @Cabal >= 1.16@
    at runtime.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
exposed-modules:
    Distribution.Helper
hidden-modules: Paths_cabal_helper CabalHelper.Types
                CabalHelper.Sandbox
abi: 55a65109d88a6a275db6dbdd775cab03
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cabal-helper-0.7.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cabal-helper-0.7.3.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cabal-helper-0.7.3.0
hs-libraries: HScabal-helper-0.7.3.0-8irtsA9yeTTAn5BCqOpvck
depends:
    Cabal-1.24.0.0 base-4.9.0.0 directory-1.2.6.2 filepath-1.4.1.0
    ghc-prim-0.5.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM process-1.4.2.0
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
